package com.fastest.pass.account.presentation.ui.components

import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.ColumnScope
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.statusBarsPadding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.alpha
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.ColorFilter
import androidx.compose.ui.platform.LocalFocusManager
import androidx.compose.ui.platform.LocalSoftwareKeyboardController
import androidx.compose.ui.res.colorResource
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.fastest.pass.R
import com.fastest.pass.home.presentation.ui.components.GapLine

@Composable
fun AccountScreen() {
    val keyboardController = LocalSoftwareKeyboardController.current
    val focusManager = LocalFocusManager.current

    Box(
        modifier = Modifier
            .background(colorResource(id = R.color.gray_splash))
            .fillMaxSize()
            .statusBarsPadding()
    ) {
        Column(
            modifier = Modifier
                .fillMaxSize()
                .padding(top = 0.dp)
                .statusBarsPadding()
        ) {
            Column(
                modifier = Modifier
                    .fillMaxSize()
                    .padding(top = 75.dp)
                    .clip(RoundedCornerShape(topStart = 0.dp, topEnd = 0.dp))
                    .background(colorResource(id = R.color.home_background_color),)
            ) {
                Spacer(modifier = Modifier.height(20.dp))
                AddRowAccount(title = stringResource(id = R.string.username), subTitle = "KP")
                Spacer(modifier = Modifier.height(10.dp))
                AddRowAccount(title = stringResource(id = R.string.product), subTitle = "Free Plan")
                Spacer(modifier = Modifier.height(20.dp))
                GapLine()

                Column(
                    modifier = Modifier
                        .padding(horizontal = 30.dp)
                        .padding(bottom = 20.dp)
                ) {
                    Spacer(modifier = Modifier.height(50.dp))
                    AddFeaturesRowAS(icon = R.drawable.about, title = R.string.about)
                    Spacer(modifier = Modifier.height(20.dp))
                    AddFeaturesRowAS(icon = R.drawable.help, title = R.string.helpandsupport)
                    Spacer(modifier = Modifier.height(20.dp))
                    AddFeaturesRowAS(icon = R.drawable.logout, title = R.string.logout)
                }
            }
        }
    }
}

@Composable
fun ColumnScope.AddRowAccount(title: String, subTitle: String) {
    Row(
        modifier = Modifier
            .fillMaxWidth()
            .padding(horizontal = 30.dp)
            .background(Color.Transparent)
            .height(18.dp),
        horizontalArrangement = Arrangement.SpaceBetween,
        verticalAlignment = Alignment.CenterVertically
    ) {
        Surface(
            modifier = Modifier
                .padding(start = 0.dp)
                .align(Alignment.CenterVertically),
            color = Color.Transparent
        ) {
            Text(text = "$title: ",
                color = colorResource(id = R.color.gray_splash),
                style = MaterialTheme.typography.displayMedium,
                maxLines = 1,
                modifier = Modifier
                    .weight(1f)
            )
        }
//        Spacer(modifier = Modifier.weight(1f))

        Surface(
            modifier = Modifier
                .padding(start = 0.dp)
                .align(Alignment.CenterVertically),
            color = Color.Transparent
        ) {
            Text(text = subTitle,
                color = colorResource(id = R.color.gray_splash),
                style = MaterialTheme.typography.displayMedium,
                maxLines = 1,
                modifier = Modifier
                    .weight(1f)
                    .alpha(0.8F)
            )
        }

    }
}

@Composable
fun ColumnScope.AddFeaturesRowAS(icon: Int, title: Int) {
    Row(
        modifier = Modifier
            .border(
                border = BorderStroke(1.dp, colorResource(id = R.color.white)),
                shape = RoundedCornerShape(15.dp)
            )
            .clip(RoundedCornerShape(15.dp))
            .background(colorResource(id = R.color.white))
            .padding(vertical = 15.dp)
            .fillMaxWidth(),
        horizontalArrangement = Arrangement.Start,
        verticalAlignment = Alignment.CenterVertically
    ) {
        Surface(
            modifier = Modifier.padding(start = 10.dp),
            color = Color.Transparent
        ) {
            Image(
                painter = painterResource(id = icon),
                contentDescription = "Icon",
                modifier = Modifier
                    .padding(start = 0.dp)
                    .size(34.dp)
                    .weight(1f),
                colorFilter = ColorFilter.tint(colorResource(id = R.color.gray_splash)),
            )
        }

        Surface(
            modifier = Modifier.padding(start = 15.dp, end = 5.dp),
            color = Color.Transparent
        ) {
            Text(
                text = stringResource(id = title),
                style = MaterialTheme.typography.displayMedium,
                color = colorResource(id = R.color.gray_splash),
                maxLines = 1,
                modifier = Modifier
//                        .weight(1F)
            )
        }
    }
}
